@@ -16,7 +16,7 @@
 * limitations under the License.
 */
 
-#include "oned/ODRowReader.h"
+#include "ODRowReader.h"
 
 namespace ZXing {
 namespace OneD {
@@ -31,6 +31,7 @@ class Code93Reader : public RowReader
 {
 public:
 	Result decodeRow(int rowNumber, const BitArray& row, std::unique_ptr<DecodingState>& state) const override;
+	Result decodePattern(int rowNumber, const PatternView& row, std::unique_ptr<DecodingState>&) const override;
 };
 
 } // OneD
